@@ -19,6 +19,7 @@ class Packet(object):
     # id: ASCII encoded, only if id is not None
     # data: JSON dump of data payload
 
+    uses_binary_events = True
     json = _json
 
     def __init__(self, packet_type=EVENT, data=None, namespace=None, id=None,
@@ -27,7 +28,9 @@ class Packet(object):
         self.data = data
         self.namespace = namespace
         self.id = id
-        if binary or (binary is None and self._data_is_binary(self.data)):
+        if self.uses_binary_events and \
+                (binary or (binary is None and self._data_is_binary(
+                    self.data))):
             if self.packet_type == EVENT:
                 self.packet_type = BINARY_EVENT
             elif self.packet_type == ACK:
@@ -37,7 +40,7 @@ class Packet(object):
         self.attachment_count = 0
         self.attachments = []
         if encoded_packet:
-            self.attachment_count = self.decode(encoded_packet)
+            self.attachment_count = self.decode(encoded_packet) or 0
 
     def encode(self):
         """Encode the packet for transmission.
@@ -175,3 +178,13 @@ class Packet(object):
                 False)
         else:
             return False
+
+    def _to_dict(self):
+        d = {
+            'type': self.packet_type,
+            'data': self.data,
+            'nsp': self.namespace,
+        }
+        if self.id:
+            d['id'] = self.id
+        return d
